def chunks(lst, n, reverse=False):
    """return successive n-sized chunks from lst."""
    res = []
    for i in range(0, len(lst), n):
        if reverse:
            res += [reversed(lst[i:i + n])]
        else:
            res += [lst[i:i + n]]
    return res



import os

def path_maker(path_list,relative_path=''):
    p = os.path.abspath(os.path.join(os.path.dirname(__file__),relative_path))
    for i in path_list:
        p += '/'+str(i)
        if not os.path.exists(p):
            os.mkdir(p)
    return p

